<?php
    require_once '../vendor/autoload.php';

    use \Firebase\JWT\JWT;
    use \Firebase\JWT\Key;

    define('SECRET_KEY_FILE', '../secret_key.txt');

    function getStoredSecretKey() {
        if (file_exists(SECRET_KEY_FILE)) {
            $data = json_decode(file_get_contents(SECRET_KEY_FILE), true);
            if ($data['month'] === date('Y-m')) {
                return $data['key'];
            }
        }
        return null;
    }

    function validateJwt() {
        $res = [];
        $key = getStoredSecretKey();
        if (!$key) {
            $res['status'] = 'Error';
            $res['message'] = 'Secret key is missing for the current month!';
            return $res;
        }

        $headers = getallheaders();
        if (isset($headers['Authorization'])) {
            $jwt = str_replace('Bearer ', '', $headers['Authorization']);
        } else {
            $res['status'] = 'Error';
            $res['message'] = 'JWT token is missing!';
            return $res;
        }

        try {
            $decoded = JWT::decode($jwt, new Key($key, 'HS256'));
            $res['status'] = 'Success';
            $res['data'] = (array)$decoded;
            return $res;
        } catch (Exception $e) {
            $res['status'] = 'Error';
            $res['message'] = 'Token is invalid: ' . $e->getMessage();
            return $res;
        }
    }
?>
